API Reference
=============

Complete parameter documentation for all Rekha functions and classes. For usage guides and examples, see the :doc:`../user_guide/index`.

Core Functions
--------------

.. currentmodule:: rekha

.. autosummary::
   :toctree: generated/
   :nosignatures:

   line
   scatter
   bar
   histogram
   heatmap
   box
   cdf
   subplots
   set_rekha_theme

Plot Classes
------------

Advanced users can access plot classes directly for more control:

.. currentmodule:: rekha.plots

.. autosummary::
   :toctree: generated/
   :nosignatures:

   LinePlot
   ScatterPlot
   BarPlot
   HistogramPlot
   HeatmapPlot
   BoxPlot
   CDFPlot

.. currentmodule:: rekha

.. autosummary::
   :toctree: generated/
   :nosignatures:

   BasePlot

Utilities
---------

.. currentmodule:: rekha.utils

.. autosummary::
   :toctree: generated/
   :nosignatures:

   prepare_data
   validate_data
   get_color_palette
   map_colors_to_categories

